/**
  *  \file client/widgets/enginestorage.cc
  *  \brief WEngineStorageInfo widget
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/enginestorage.h"
#include "gfx/gfxcontext.h"
#include "util/nls.h"
#include "cpluslib/format.h"
#include "ui/uiglobal.h"
#include "util/misc.h"

/*************************** WEngineStorageInfo **************************/

WEngineStorageInfo::WEngineStorageInfo()
    : UIWidget(), have(0), need(0)
{ }

void
WEngineStorageInfo::setEnginesAvailable(int n)
{
    if (n != have) {
        have = n;
        drawWidget(false);
    }
}

void
WEngineStorageInfo::setEnginesNeeded(int n)
{
    if (n != need) {
        need = n;
        drawWidget(false);
    }
}

void
WEngineStorageInfo::drawContent(GfxCanvas& can)
{
    int x = getExtent().x, y = getExtent().y, wi = getExtent().w;

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_TITLE]);
    ctx.setColor(UIColor::tc_White);
    ctx.setSolidBackground();
    outTextF(ctx, x, y, wi, format(_("Ship requires %d engine%!1{s%}."), need));
    y += font_heights[FONT_TITLE];

    ctx.useFont(*fonts[FONT_NORMAL]);
    outTextF(ctx, x, y, wi, format(_("In storage: %d engine%!1{s%}."), numToString(have)));
    y += font_heights[FONT_NORMAL];

    can.update(getExtent());
}

void
WEngineStorageInfo::getLayoutInfo(LayoutInfo& info)
{
    info.min_size = info.pref_size =
        font_sizes[FONT_NORMAL].scaledBy(15, 1).movedBy(0, font_heights[FONT_TITLE]);
    info.flags = 0;
}
