/**
  *  \file game/obj.cc
  *  \brief Game Object Base Classes
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/obj.h"

/******************************** GObject ********************************/

/** Destructor. */
GObject::~GObject()
{ }

/** Convert to string. Implemented for GObject using getName(LongName). */
string_t
GObject::toString()
{
    return getName(LongName);
}

/** Notify all listeners. If this object is dirty, raise sig_changed
    and reset dirtiness state.

    You should not use this directly. Use GUniverse::doScreenUpdates()
    instead, which offers more flexibility for users to hook into
    universe change. In particular, widgets that hook into
    GUniverse::sig_pre_update (those that observe lots of objects)
    will not be notified by a lone notifyListeners(). */
void
GObject::notifyListeners()
{
    if (is_dirty) {
        is_dirty = false;
        sig_changed.raise(getId());
    }
}



/******************************* GMapObject ******************************/

GMapObject::~GMapObject()
{ }



/**************************** GCircularObject ****************************/

GCircularObject::~GCircularObject()
{ }
